==> killbill-platform-lifecycle-0.36.12-sources.jar: org/killbill/billing/lifecycle/bus/DefaultExternalBusService.java <==
/*
 * Copyright 2014 Groupon, Inc
 * Copyright 2014 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.killbill.billing.lifecycle.bus;

import org.killbill.billing.lifecycle.api.ExternalBusService;
import org.killbill.billing.lifecycle.glue.BusModule;
import org.killbill.billing.platform.api.LifecycleHandlerType;
import org.killbill.bus.api.PersistentBus;

import com.google.inject.Inject;
import com.google.inject.name.Named;

public class DefaultExternalBusService implements ExternalBusService {

    public static final String EXTERNAL_BUS_SERVICE = "external-bus-service";

    private final PersistentBus eventBus;

    @Inject
    public DefaultExternalBusService(@Named(BusModule.EXTERNAL_BUS_NAMED) final PersistentBus eventBus) {
        this.eventBus = eventBus;
    }

    @Override
    public String getName() {
        return EXTERNAL_BUS_SERVICE;
    }

    @LifecycleHandlerType(LifecycleHandlerType.LifecycleLevel.INIT_BUS)
    public void startBus() {
        eventBus.start();
    }

    @LifecycleHandlerType(LifecycleHandlerType.LifecycleLevel.STOP_BUS)
    public void stopBus() {
        eventBus.stop();
    }

    @Override
    public PersistentBus getBus() {
        return eventBus;
    }
}

==> killbill-platform-lifecycle-0.39.11-sources.jar: org/killbill/billing/lifecycle/bus/DefaultExternalBusService.java <==
/*
 * Copyright 2014 Groupon, Inc
 * Copyright 2014 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.killbill.billing.lifecycle.bus;

import org.killbill.billing.lifecycle.api.ExternalBusService;
import org.killbill.billing.lifecycle.glue.BusModule;
import org.killbill.billing.platform.api.LifecycleHandlerType;
import org.killbill.bus.api.PersistentBus;

import com.google.inject.Inject;
import com.google.inject.name.Named;

public class DefaultExternalBusService implements ExternalBusService {

    private final PersistentBus eventBus;

    @Inject
    public DefaultExternalBusService(@Named(BusModule.EXTERNAL_BUS_NAMED) final PersistentBus eventBus) {
        this.eventBus = eventBus;
    }

    @Override
    public String getName() {
        return KILLBILL_SERVICES.EXTERNAL_BUS_SERVICE.getServiceName() ;
    }

    @Override
    public int getRegistrationOrdering() {
        return KILLBILL_SERVICES.EXTERNAL_BUS_SERVICE.getRegistrationOrdering() ;
    }

    @LifecycleHandlerType(LifecycleHandlerType.LifecycleLevel.INIT_BUS)
    public void startBus() {
        eventBus.start();
    }

    @LifecycleHandlerType(LifecycleHandlerType.LifecycleLevel.STOP_BUS)
    public void stopBus() {
        eventBus.stop();
    }

    @Override
    public PersistentBus getBus() {
        return eventBus;
    }
}
